# <p align="center"> Aiogramarch </p>
<p align="center">Project manager and generator for Aiogram</p>




## Installation

``` python
pip install aiogramarch
```

## How to use

``` bash
aiogramarch startproject [projectname]
```

``` bash
cd codingbot
```

``` bash
aiogramarch startapp [appname]
```

``` bash
aiogramarch includeRedis
```

``` bash
aiogramarch includeFastApi
```

``` bash
aiogramarch includeAdmin
```

#### To find out all the functions:

``` bash
aiogramarch --help
```


